@@ -9,7 +9,7 @@
     'name_es_ES': 'Empresa',
     'name_fr_FR': 'Société',
     'name_nl_NL': 'Bedrijf',
-    'version': '2.0.2',
+    'version': '2.2.0',
     'author': 'B2CK',
     'email': 'info@b2ck.com',
     'website': 'http://www.tryton.org/',
@@ -80,12 +80,13 @@ Lance les planificateurs sur chaque société.
         'cron.xml',
     ],
     'translation': [
-        'bg_BG.csv',
-        'de_DE.csv',
-        'es_CO.csv',
-        'es_ES.csv',
-        'fr_FR.csv',
-        'nl_NL.csv',
-        'ru_RU.csv',
+        'locale/bg_BG.po',
+        'locale/cs_CZ.po',
+        'locale/de_DE.po',
+        'locale/es_CO.po',
+        'locale/es_ES.po',
+        'locale/fr_FR.po',
+        'locale/nl_NL.po',
+        'locale/ru_RU.po',
     ]
 }
